@@ -384,11 +384,9 @@ def dropout(image, prob=0.75, ct=8, sz=0.2, rank=2):
     # Calculate square/box size
     sq_height = tf.cast(sz * h, tf.int32) * P
     sq_width = tf.cast(sz * w, tf.int32) * P
-    print(sq_height, sq_width)
 
     if rank == 3:
         sq_depth = tf.cast(sz * d, tf.int32) * P
-        print(sq_depth)
 
     # generate random black squares
     for k in range(ct):
